"""
Examples of using request and response messages
"""

from mqtt_protocol import (
    SwapStartRequest,
    SwapStartResponse,
    ChargeStartRequest,
    ChargeStartResponse
)
from mqtt_protocol.request_response import (
    RateModelQuery,
    RateModelResponse,
    RateInfo,
    RateTimeSegment
)


def swap_request_example():
    # Create a swap start request
    swap_req = SwapStartRequest(
        vin="LSVAA12345G123456",
        rfid_code="123456789012345678901234",
        plate_no="京A12345",
        lane=1,
        user_id="USER001"
    )

    print("Swap Start Request Example:")
    print(swap_req.to_json())

    # Create a response
    swap_resp = SwapStartResponse(
        vin="LSVAA12345G123456",
        rfid_code="123456789012345678901234",
        plate_no="京A12345",
        result=1,  # Success
        order_sn="SR202402240001"
    )

    print("\nSwap Start Response Example:")
    print(swap_resp.to_json())


def charge_request_example():
    # Create a charge start request
    charge_req = ChargeStartRequest(
        chg_id="CHG001",
        gun_no=1
    )

    print("\nCharge Start Request Example:")
    print(charge_req.to_json())

    # Create a response
    charge_resp = ChargeStartResponse(
        result=1,  # Success
        chg_id="CHG001",
        gun_no=1,
        order_sn="CR202402240001"
    )

    print("\nCharge Start Response Example:")
    print(charge_resp.to_json())


def rate_model_example():
    # Create rate model query
    rate_query = RateModelQuery("RATE001")
    print("\nRate Model Query Example:")
    print(rate_query.to_json())

    # Create rate info list
    rate_list = [
        RateInfo(rateType=1, electPrice=1.2, servicePrice=0.5),
        RateInfo(rateType=2, electPrice=1.0, servicePrice=0.4),
        RateInfo(rateType=3, electPrice=0.8, servicePrice=0.3),
        RateInfo(rateType=4, electPrice=0.6, servicePrice=0.2)
    ]

    # Create rate time segments
    time_segments = [
        RateTimeSegment(rateType=1, index=1,
                        startTime="10:00:00", stopTime="12:00:00"),
        RateTimeSegment(rateType=2, index=2,
                        startTime="12:00:00", stopTime="14:00:00")
    ]

    # Create response
    rate_resp = RateModelResponse(
        rate_model_id="RATE001",
        rate_list=rate_list,
        rate_details_list=time_segments
    )

    print("\nRate Model Response Example:")
    print(rate_resp.to_json())


if __name__ == "__main__":
    swap_request_example()
    charge_request_example()
    rate_model_example()