import paho.mqtt.client as mqtt
import json

class MQTTClient:
    def __init__(self):
        self.client = mqtt.Client(client_id="GoClientExample", protocol=mqtt.MQTTv311,
                                callback_api_version=mqtt.CallbackAPIVersion.VERSION1)
        self.client.username_pw_set("emqx_test", "emqx_test")
        self.client.on_connect = self.on_connect
        self.client.on_disconnect = self.on_disconnect
        self.connected = False

    def on_connect(self, client, userdata, flags, rc):
        if rc == 0:
            print("Connected to MQTT broker")
            self.connected = True
        else:
            print(f"Failed to connect to MQTT broker with code: {rc}")

    def on_disconnect(self, client, userdata, rc):
        print("Disconnected from MQTT broker")
        self.connected = False

    def connect(self):
        try:
            self.client.connect("123.6.102.119", 1883, 60)
            self.client.loop_start()
        except Exception as e:
            print(f"MQTT connection error: {str(e)}")

    def publish_message(self, message):
        try:
            if self.connected:
                self.client.publish("hejin/charging/log", json.dumps(message), qos=1)
            else:
                print("MQTT client not connected")
        except Exception as e:
            print(f"MQTT publish error: {str(e)}")

    def disconnect(self):
        self.client.loop_stop()
        self.client.disconnect()